aboutsummaryrefslogtreecommitdiff
path: root/src/compat
diff options
context:
space:
mode:
Diffstat (limited to 'src/compat')
-rw-r--r--src/compat/assumptions.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/compat/assumptions.h b/src/compat/assumptions.h
index 301c2d914c..e8d0c7d56e 100644
--- a/src/compat/assumptions.h
+++ b/src/compat/assumptions.h
@@ -17,15 +17,15 @@
# error "Bitcoin cannot be compiled without assertions."
#endif
-// Assumption: We assume a C++11 (ISO/IEC 14882:2011) compiler (minimum requirement).
-// Example(s): We assume the presence of C++11 features everywhere :-)
+// Assumption: We assume a C++17 (ISO/IEC 14882:2017) compiler (minimum requirement).
+// Example(s): We assume the presence of C++17 features everywhere :-)
// Note: MSVC does not report the expected __cplusplus value due to legacy
// reasons.
#if !defined(_MSC_VER)
// ISO Standard C++11 [cpp.predefined]p1:
// "The name __cplusplus is defined to the value 201103L when compiling a C++
// translation unit."
-static_assert(__cplusplus >= 201103L, "C++11 standard assumed");
+static_assert(__cplusplus >= 201703L, "C++17 standard assumed");
#endif
// Assumption: We assume the floating-point types to fulfill the requirements of
@@ -17,15 +17,15 @@
// reasons.
#if !defined(_MSC_VER)
-// ISO Standard C++11 [cpp.predefined]p1:
-// "The name __cplusplus is defined to the value 201103L when compiling a C++
+// ISO Standard C++17 [cpp.predefined]p1:
+// "The name __cplusplus is defined to the value 201703L when compiling a C++
// translation unit."